Class: Skylight::Normalizers::Grape::EndpointRun Private

Inherits:
Endpoint show all
Defined in:
lib/skylight/normalizers/grape/endpoint_run.rb

This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.

Instance Attribute Summary

Attributes inherited from Normalizer

#config

Instance Method Summary collapse

Methods inherited from Normalizer

#initialize, #normalize_after, #normalize_with_meta, register

Methods included from Util::Logging

#config_for_logging, #debug, #error, #fmt, #info, #log, #log_context, #raise_on_error?, #t, #trace, #trace?, #warn

Constructor Details

This class inherits a constructor from Skylight::Normalizers::Normalizer

Instance Method Details

#normalize(trace, _name, payload) ⇒ Object

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



7
8
9
10
11
12
13
# File 'lib/skylight/normalizers/grape/endpoint_run.rb', line 7

def normalize(trace, _name, payload)
  trace.endpoint = get_endpoint_name(payload[:endpoint]) if payload[:endpoint]

  # We don't necessarily want this to be all instrumented since it's fairly internal.
  # However, it is a good place to get the endpoint name.
  :skip
end