Module: Skylight::Probes::Lambda::Runner Private
- Defined in:
- lib/skylight/probes/lambda.rb
Overview
This module is part of a private API. You should avoid using this module if possible, as it may be removed or be changed in the future.
NOTE: there are two modalities to probing the lambda wrappers:
-
The default runtime is implemented as a plain set of nested loops; LambdaHandler is a top-level constant in this context.
-
AWS also publishes the aws_lambda_ric gem as an alternate Dockerfile entrypoint; this runs largely the same code, but encapsulated in the LambdaRunner.
The ‘run_user_code` is by all measures a better method to probe, as it includes the time spent to deliver the response back to the lambda server, and we can flush the internal buffer here without affecting response time.
Defined Under Namespace
Modules: Instrumentation Classes: Probe