Module: Skylight::Probes::Middleware::Instrumentation Private
- Defined in:
- lib/skylight/probes/middleware.rb
Overview
This module is part of a private API. You should avoid using this module if possible, as it may be removed or be changed in the future.
for Rails <= 5.2 ActionDispatch::MiddlewareStack::Middleware
Class Method Summary collapse
Instance Method Summary collapse
- #build ⇒ Object private
Class Method Details
.sk_instrument_middleware(middleware) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
30 31 32 33 34 35 36 37 38 39 40 41 42 |
# File 'lib/skylight/probes/middleware.rb', line 30 def self.sk_instrument_middleware(middleware) return middleware if middleware.is_a?(Skylight::Middleware) # Not sure how this would actually happen return middleware if middleware.respond_to?(:__has_sk__) # On Rails 3, ActionDispatch::Session::CookieStore is frozen, for one return middleware if middleware.frozen? Skylight::Probes::Middleware::Probe.add_instrumentation(middleware) middleware end |
Instance Method Details
#build ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
26 27 28 |
# File 'lib/skylight/probes/middleware.rb', line 26 def build(*) Instrumentation.sk_instrument_middleware(super) end |